@@ -11,7 +11,8 @@
 #   under the License.
 #
 
-import mock
+from unittest import mock
+
 from osc_lib import exceptions as exc
 import yaml
 
